@@ -5,7 +5,7 @@ use warnings;
 
 use Alien::Base::PkgConfig;
 
-our $VERSION = '0.022_01';
+our $VERSION = '0.023_01';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -18,6 +18,8 @@ use Capture::Tiny 0.17 qw/capture_merged/;
 use Text::ParseWords qw/shellwords/;
 use Perl::OSType qw/os_type/;
 
+=encoding UTF-8
+
 =head1 NAME
 
 Alien::Base - Base classes for Alien:: modules
@@ -298,9 +300,11 @@ sub _keyword {
 
   if(defined $self->config('original_prefix') && $self->config('original_prefix') ne $self->dist_dir)
   {
+    my $dist_dir = $self->dist_dir;
+    $dist_dir =~ s{\\}{/}g if $^O eq 'MSWin32';
     my $old = quotemeta $self->config('original_prefix');
     @strings = map {
-      s{^(-I|-L|-LIBPATH:)?($old)}{$1.$self->dist_dir}e;
+      s{^(-I|-L|-LIBPATH:)?($old)}{$1.$dist_dir}e;
       s/(\s)/\\$1/g;
       $_;
     } map { $self->split_flags($_) } @strings;
@@ -654,6 +658,8 @@ Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt> and the L<Alien::Ba
 
 =item Flavio Poletti (polettix)
 
+=item Salvador Fandiño (salva)
+
 =back
 
 Thanks also to
