@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.022_01';
+our $VERSION = '0.023_01';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -323,6 +323,15 @@ sub process_share_dir_files {
   $self->depends_on('alien_install') if $self->notes('alien_blib_scheme') || $self->alien_stage_install;
 }
 
+sub alien_extract_archive {
+  my ($self, $archive) = @_;
+  print "Extracting Archive ... ";
+  my $ae = Archive::Extract->new( archive => $archive );
+  $ae->extract or croak "Archive extraction failed!";
+  print "Done\n";
+  return $ae->extract_path;
+}
+
 sub ACTION_alien_code {
   my $self = shift;
   local $| = 1; # don't buffer stdout
@@ -374,12 +383,8 @@ sub ACTION_alien_code {
     croak "Error downloading file" unless $filename;
     print "Done\n";
 
-    print "Extracting Archive ... ";
-    my $ae = Archive::Extract->new( archive => $filename );
-    $ae->extract;
-    print "Done\n";
+    my $extract_path = _catdir(File::Spec->rel2abs($self->alien_extract_archive($filename)));
 
-    my $extract_path = _catdir($ae->extract_path);
     $self->config_data( working_directory => $extract_path );
     $CWD = $extract_path;
 
@@ -479,6 +484,7 @@ sub ACTION_alien_install {
     }
   }
 
+  if(!$self->config_data( 'finished_installing' ))
   {
     local $CWD = $self->config_data( 'working_directory' );
     local $ENV{DESTDIR} = $ENV{DESTDIR};
@@ -686,7 +692,7 @@ sub _alien_bin_require {
   }
 }
 
-sub _env_do_system {
+sub alien_do_system {
   my $self = shift;
   my $command = shift;
   
@@ -775,6 +781,9 @@ sub _env_do_system {
   $self->do_system( ref($command) ? @$command : $command );
 }
 
+# alias for backwards compatibility
+*_env_do_system = \&alien_do_system;
+
 sub alien_check_built_version {
   return;
 }
@@ -790,7 +799,7 @@ sub alien_do_commands {
 
   foreach my $command (@$commands) {
 
-    my %result = $self->_env_do_system( $command );
+    my %result = $self->alien_do_system( $command );
     unless ($result{success}) {
       carp "External command ($result{command}) failed! Error: $?\n";
       return 0;
@@ -1160,7 +1169,7 @@ In your Build.PL:
 
  use Alien::Base::ModuleBuild;
  
- my $builder = Alien::Base::Module::Build->new(
+ my $builder = Alien::Base::ModuleBuild->new(
    module_name => 'Alien::MyLibrary',
    
    configure_requires => {
@@ -1246,6 +1255,31 @@ If you see an error message like this:
 After the package is built from source code then you probably need to
 provide an implementation for this method.
 
+=head2 alien_extract_archive
+
+  my $dir = $amb->alien_extract_archive($filename);
+
+This function unpacks the given archive and returns the directory
+containing the unpacked files.
+
+The default implementation relies on L<Archive::Extract> that is able
+to handle most common formats. In order to handle other formats or
+archives requiring some special treatment you may want to override
+this method.
+
+=head2 alien_do_system
+
+  my %result = $amb->alien_do_system($cmd)
+
+Similar to L<Module::Build::do_system>, also sets the path and several
+environment variables in accordance to the object configuration
+(i.e. C<alien_bin_requires>) and performs the interpolation of the
+patterns described in L<Alien::Base::ModuleBuild::API/COMMAND
+INTERPOLATION>.
+
+Returns a set of key value pairs including C<stdout>, C<stderr>,
+C<success> and C<command>.
+
 =head1 GUIDE TO DOCUMENTATION
 
 The documentation for C<Module::Build> is broken up into sections:
